Crate geronimo_captcha

Crate geronimo_captcha 

Structs

CaptchaChallenge
CaptchaManager
ChallengeInMemoryRegistry
GenerationOptions
NoiseOptions

Enums

CaptchaError
RegistryCheckResult

Traits

ChallengeRegistry
This file defines trait for the challenge registry implementation that stores generated challenges in memory or database, checks how many resolving attempts performed to prevent brute-force.

Type Aliases

Result