ChallengeRegistry

Trait ChallengeRegistry 

pub trait ChallengeRegistry: Send + Sync {
    // Required methods
    fn register(&self, id: &str);
    fn check(&self, id: &str) -> RegistryCheckResult;
    fn verify(&self, id: &str);
    fn note_attempt(&self, id: &str, success: bool);
}
This file defines trait for the challenge registry implementation that stores generated challenges in memory or database, checks how many resolving attempts performed to prevent brute-force.

Required Methods

fn register(&self, id: &str)

fn check(&self, id: &str) -> RegistryCheckResult

fn verify(&self, id: &str)

fn note_attempt(&self, id: &str, success: bool)

Implementors