Crate geronimo_captcha
geronimo_
captcha
0.2.0
All Items
Crate Items
Structs
Enums
Traits
Type Aliases
Crate
geronimo_
captcha
Structs

Captcha
Challenge
Captcha
Manager
Challenge
InMemory
Registry
Generation
Options
Noise
Options
Enums

Captcha
Error
Registry
Check
Result
Traits

Challenge
Registry
This file defines trait for the challenge registry implementation that stores generated challenges in memory or database, checks how many resolving attempts performed to prevent brute-force.
Type Aliases

Result